import { ActionFormData } from '@minecraft/server-ui';
import { world } from '@minecraft/server';

world.afterEvents.entityDie.subscribe((event) => {
  const entity = event.deadEntity;

  if (entity.typeId === "minecraft:player") {
    try {
      const { x, y, z } = entity.location;
      const playerName = entity.nameTag;

      entity.dimension.runCommandAsync(`summon zc:grave ${x} ${y} ${z}`);
      
      entity.dimension.runCommandAsync(`tp @e[type=item,x=${x}, y=${y}, z=${z},r=7] ${x} ${y} ${z}`);
      
      entity.dimension.runCommandAsync(`tickingarea add ${x-1} ${y-1} ${z-1} ${x+1} ${y+1} ${z+1}`);
      
      entity.dimension.runCommandAsync(`tag @e[type=zc:grave, x=${x}, y=${y}, z=${z}, r=1] add ${playerName}`);

      world.afterEvents.playerSpawn.subscribe((spawnEvent) => {
        if (spawnEvent.player.nameTag === playerName) {
          try {
            spawnEvent.player.runCommandAsync(`effect @s water_breathing 30 10 true`);
            spawnEvent.player.runCommandAsync(`effect @s slow_falling 30 10 true`);
            spawnEvent.player.runCommandAsync(`effect @s fire_resistance 30 3 true`);
            spawnEvent.player.runCommandAsync(`effect @s invisibility 30 3 true`);

            spawnEvent.player.runCommandAsync(`give @s zc:grave_res 1`);
            spawnEvent.player.runCommandAsync(`give @s zc:grave_key 1`);

            spawnEvent.player.runCommandAsync(`clear @s zc:grave_res 1 1`);
            spawnEvent.player.runCommandAsync(`clear @s zc:grave_key 1 1`);
          } catch (error) {
            console.error(`Failed to apply effects or give items: ${error}`);
          }
        }
      });

    } catch (error) {
      console.error(`Failed to process player death: ${error}`);
    }
  }
});





function showGraveUI(player) {
  const ui = new ActionFormData()
    .title("§l§4Master Grave Actions")
    .body("§l§6Select an action:")
    .button("§l§5Open Grave", "textures/items/bone")
    .button("§l§5Clear Key", "textures/ui/trash"); 

  ui.show(player).then((response) => {
    if (response.canceled) return; 

    switch (response.selection) {
      case 0: 
        try {
          
          player.runCommandAsync(
            `tag @s add mwn`
          );
          player.runCommandAsync(
            `execute @e[type=zc:grave,c=1,r=7] ~~~ function mgopen`
          );
          player.runCommandAsync(
            `tag @s remove mwn`
          );
          
          
        } catch (error) {
          player.sendMessage("§cAn error occurred while processing your request.");
          console.error(`Grave command error: ${error}`);
        }
        break;

      case 1: 
        try {
          player.runCommandAsync(`clear @s zc:mgkey 0 1`);
        } catch (error) {
          player.sendMessage("§cFailed to clear Grave Key!");
          console.error(`Clear Key command error: ${error}`);
        }
        break;

      default:
        break;
    }
  });
}

world.afterEvents.itemUse.subscribe((event) => {
  const { source, itemStack } = event;

  if (source && itemStack.typeId === "zc:mgkey") {
    showGraveUI(source);
  }
});


system.runInterval(() => {
    world.getDimension("overworld").runCommandAsync("clear @a[hasitem={item=zc:grave_key, quantity=2..}] zc:grave_key 0 1");
    world.getDimension("overworld").runCommandAsync("clear @a[hasitem={item=zc:grave_res, quantity=2..}] zc:grave_res 0 1");
}, 20);


